screen = {
		width = love.graphics.getWidth(),
		height = love.graphics.getHeight()
	}
	
color = {
		background = {0, 16, 32, 255},
		face = {0, 32, 64, 255},
		text = {0, 16, 32, 255},
		second_hand = {0, 64, 128, 255},
		minute_hand = {0, 64, 128, 255},
		hour_hand = {0, 64, 128, 255},
		hour_dots = {0, 64, 128},
		second_dots = {0, 16, 32, 255}
	}
	
local hour, minute, second = 0, 0, 0

local radius = (screen.width / 2) - (screen.width / 32)

local second_hand = {
		radius = (radius / 8) * 7,
		angle = 0,
		x = 0,
		y = 0
	}
	
local minute_hand = {
		radius = (radius / 8) * 5,
		angle = 0,
		x = 0,
		y = 0
	}
	
local hour_hand = {
		radius = (radius / 8) * 4,
		angle = 0,
		x = 0,
		y = 0
	}
	
local hour_dots = {}
for i=1, 12 do
	local d = {
			angle = ((math.pi * 2) / 12) * i
		}
		d.x = ((radius / 12) * 11) * math.cos(d.angle) + (screen.width / 2)
		d.y = ((radius / 12) * 11) * math.sin(d.angle) + (screen.height / 2)
	hour_dots[#hour_dots + 1] = d
end

local second_dots = {}
for i=1, 60 do
	local d = {
			angle = ((math.pi * 2) / 60) * i
		}
		d.x = ((radius / 12) * 11) * math.cos(d.angle) + (screen.width / 2)
		d.y = ((radius / 12) * 11) * math.sin(d.angle) + (screen.height / 2)
	second_dots[#second_dots + 1] = d
end

function love.load()
	love.graphics.setBackgroundColor(color.background)
end

function love.update(dt)
	hour = os.date("%I")
	minute = os.date("%M")
	second = os.date("%S")
	
	--Second hand update
	second_hand.angle = ((math.pi * 2) / 60) * second - (math.pi / 2)
	second_hand.x = second_hand.radius * math.cos(second_hand.angle) + (screen.width / 2)
	second_hand.y = second_hand.radius * math.sin(second_hand.angle) + (screen.height / 2)
	
	--Minute hand update
	minute_hand.angle = ((math.pi * 2) / 60) * minute - (math.pi / 2)
	minute_hand.x = minute_hand.radius * math.cos(minute_hand.angle) + (screen.width / 2)
	minute_hand.y = minute_hand.radius * math.sin(minute_hand.angle) + (screen.height / 2)
	
	--Hour hand update
	hour_hand.angle = (((math.pi * 2) / 12) * hour - (math.pi / 2)) + (((math.pi * 2) / 12) / 60) * minute
	hour_hand.x = hour_hand.radius * math.cos(hour_hand.angle) + (screen.width / 2)
	hour_hand.y = hour_hand.radius * math.sin(hour_hand.angle) + (screen.height / 2)

end

function love.draw()
	--Face
	love.graphics.setColor(color.face)
	love.graphics.circle("fill", screen.width / 2, screen.height / 2, radius)
	
	--HANDS
	--second
	love.graphics.setColor(color.second_hand)
	love.graphics.line(screen.width / 2, screen.height / 2, second_hand.x, second_hand.y)
	--minute
	love.graphics.setColor(color.minute_hand)
	love.graphics.line(screen.width / 2, screen.height / 2, minute_hand.x, minute_hand.y)
	--hour
	love.graphics.setColor(color.hour_hand)
	love.graphics.line(screen.width / 2, screen.height / 2, hour_hand.x, hour_hand.y)
	
	--Second dots
	love.graphics.setColor(color.second_dots)
	for i,v in ipairs(second_dots) do
		love.graphics.circle("fill", v.x, v.y, radius * 0.01)
	end
	--Hour dots
	love.graphics.setColor(color.hour_dots)
	for i,v in ipairs(hour_dots) do
		love.graphics.circle("fill", v.x, v.y, radius * 0.02)
	end

	local s = hour.." : "..minute.." : "..second
	love.graphics.setColor(color.text)
	love.graphics.print(s, (screen.width / 2) - (love.graphics.getFont():getWidth(s) / 2), (screen.height / 6) * 4)
end

function love.keypressed(key)
	if key == "escape" then love.event.push("quit") end
end


function love.resize(w, h)
	local _w, _h, f = love.window.getMode()
	local size = w
	if w > h then
		size = h
	end
	love.window.setMode(size, size, f)
	screen.width, screen.height = size, size
	
	radius = (size / 2) - (screen.width / 32)
	--Fixing Dots
	for i,v in ipairs(second_dots) do
		v.x = ((radius / 12) * 11) * math.cos(v.angle) + (screen.width / 2)
		v.y = ((radius / 12) * 11) * math.sin(v.angle) + (screen.height / 2)
	end
	for _i,b in ipairs(hour_dots) do
		b.x = ((radius / 12) * 11) * math.cos(b.angle) + (screen.width / 2)
		b.y = ((radius / 12) * 11) * math.sin(b.angle) + (screen.height / 2)
	end
	
	--Fixing Hands
	second_hand.radius = (radius / 8) * 7
	minute_hand.radius = (radius / 8) * 5
	hour_hand.radius = (radius / 8) * 4

end
